package erasurecode_test

import (
	"testing"

	"git.frostfs.info/TrueCloudLab/frostfs-sdk-go/object/erasurecode"
	"github.com/nspcc-dev/neo-go/pkg/crypto/keys"
	"github.com/stretchr/testify/require"
)

// The library can behave differently for big shard counts.
// This test checks we support the maximum number of chunks we promise.
func TestSplitMaxShardCount(t *testing.T) {
	pk, err := keys.NewPrivateKey()
	require.NoError(t, err)

	original := newObject(t, 1024, pk)

	t.Run("only data", func(t *testing.T) {
		c, err := erasurecode.NewConstructor(erasurecode.MaxShardCount, 0)
		require.NoError(t, err)

		parts, err := c.Split(original, &pk.PrivateKey)
		require.NoError(t, err)
		require.Len(t, parts, erasurecode.MaxShardCount)
	})
	t.Run("data + parity", func(t *testing.T) {
		c, err := erasurecode.NewConstructor(1, erasurecode.MaxShardCount-1)
		require.NoError(t, err)

		parts, err := c.Split(original, &pk.PrivateKey)
		require.NoError(t, err)
		require.Len(t, parts, erasurecode.MaxShardCount)
	})

}
